@@ -3,18 +3,16 @@ import json
 from django.conf import settings
 from django.contrib.humanize.templatetags.humanize import intcomma
 from django.db import models, transaction
+from django.db.models import Max
 from django.utils.functional import cached_property
 from django.utils.module_loading import import_string
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.common.serialization import yaml_load
-from mayan.apps.common.validators import YAMLValidator
 from mayan.apps.documents.models.document_type_models import DocumentType
 from mayan.apps.events.classes import (
     EventManagerMethodAfter, EventManagerSave
 )
 from mayan.apps.events.decorators import method_event
-from mayan.apps.metadata.models import MetadataType
 
 from credentials.models import StoredCredential
 
@@ -25,9 +23,9 @@ from .events import (
 )
 from .literals import (
     DEFAULT_PROCESS_SIZE, ITEM_STATE_CHOICES, ITEM_STATE_COMPLETE,
-    ITEM_STATE_DOWNLOADED, ITEM_STATE_ERROR, ITEM_STATE_QUEUED,
-    ITEM_STATE_NONE, SETUP_STATE_CHOICES, SETUP_STATE_ERROR,
-    SETUP_STATE_EXECUTING, SETUP_STATE_NONE, SETUP_STATE_POPULATING
+    ITEM_STATE_DOWNLOADED, ITEM_STATE_ERROR, ITEM_STATE_NONE,
+    SETUP_STATE_CHOICES, SETUP_STATE_ERROR, SETUP_STATE_EXECUTING,
+    SETUP_STATE_NONE, SETUP_STATE_POPULATING
 )
 from .tasks import task_import_setup_item_process
 
@@ -61,6 +59,9 @@ class BackendModelMixin(models.Model):
                     raise
             return NullBackend
 
+    def get_backend_instance(self):
+        return self.get_backend()(**self.get_backend_data())
+
     def get_backend_label(self):
         """
         Return the label that the backend itself provides. The backend is
@@ -72,6 +73,12 @@ class BackendModelMixin(models.Model):
     get_backend_label.short_description = _('Backend')
     get_backend_label.help_text = _('The backend class for this entry.')
 
+    def get_backend_label(self):
+        try:
+            return self.get_backend().label
+        except ImportError:
+            return _('Unknown action type')
+
     def get_backend_data(self):
         return json.loads(s=self.backend_data or '{}')
 
@@ -98,13 +105,6 @@ class ImportSetup(BackendModelMixin, models.Model):
             'Number of items to process per execution.'
         ), verbose_name=_('Process size.')
     )
-    metadata_map = models.TextField(
-        blank=True, help_text=_(
-            'A YAML encoded dictionary to save the content of the item '
-            'properties as metadata values. The dictionary must consist of '
-            'an import item property key matched to a metadata type name.'
-        ), validators=[YAMLValidator()], verbose_name=_('Metadata map')
-    )
     state = models.PositiveIntegerField(
         choices=SETUP_STATE_CHOICES, default=SETUP_STATE_NONE, help_text=_(
             'The last recorded state of the import setup.'
@@ -254,6 +254,54 @@ class ImportSetup(BackendModelMixin, models.Model):
         return super().save(*args, **kwargs)
 
 
+class ImportSetupAction(BackendModelMixin, models.Model):
+    import_setup = models.ForeignKey(
+        on_delete=models.CASCADE, related_name='actions', to=ImportSetup,
+        verbose_name=_('Import Setup')
+    )
+    label = models.CharField(
+        max_length=255, help_text=_('A short text describing the action.'),
+        verbose_name=_('Label')
+    )
+    enabled = models.BooleanField(default=True, verbose_name=_('Enabled'))
+    order = models.PositiveIntegerField(
+        blank=True, db_index=True, default=0, help_text=_(
+            'Order in which the action will be executed. If left '
+            'unchanged, an automatic order value will be assigned.'
+        ), verbose_name=_('Order')
+    )
+
+    class Meta:
+        ordering = ('order', 'label')
+        unique_together = (('import_setup', 'order'), ('import_setup', 'label'))
+        verbose_name = _('Import setup action')
+        verbose_name_plural = _('Import setup actions')
+
+    def __str__(self):
+        return self.label
+
+    def execute(self, context=None):
+        if not context:
+            context = {}
+
+        return self.get_backend_instance().execute(context=context)
+
+    def get_next_order(self):
+        last_order = self.import_setup.actions.aggregate(
+            Max('order')
+        )['order__max']
+
+        if last_order is not None:
+            return last_order + 1
+        else:
+            return 0
+
+    def save(self, *args, **kwargs):
+        if not self.order:
+            self.order = self.get_next_order()
+        super().save(*args, **kwargs)
+
+
 class ImportSetupItem(models.Model):
     import_setup = models.ForeignKey(
         on_delete=models.CASCADE, related_name='items',
@@ -318,16 +366,7 @@ class ImportSetupItem(models.Model):
                 self.save()
                 shared_uploaded_file.delete()
 
-        if document:
-            item_setup_metadata_map = yaml_load(
-                stream=self.import_setup.metadata_map or '{}'
-            )
-
-            for key, metadata_name in item_setup_metadata_map.items():
-                document.metadata.create(
-                    metadata_type=MetadataType.objects.get(name=metadata_name),
-                    value=self.data.get(key)
-                )
+        return document
 
     @cached_property
     def data(self):
@@ -385,4 +424,10 @@ class ImportSetupItem(models.Model):
                 self.save()
 
         if shared_uploaded_file:
-            self.create_document(shared_uploaded_file=shared_uploaded_file)
+            document = self.create_document(
+                shared_uploaded_file=shared_uploaded_file
+            )
+            if document:
+                context = {'document': document, 'self': self}
+                for action in self.import_setup.actions.all():
+                    action.execute(context=context)
