@@ -4,7 +4,7 @@ from mayan.apps.documents.tests.mixins import DocumentTestMixin
 
 from credentials.tests.mixins import CredentialTestMixin
 
-from ..models import ImportSetup, ImportSetupItem
+from ..models import ImportSetup, ImportSetupAction, ImportSetupItem
 from ..permissions import (
     permission_import_setup_create, permission_import_setup_delete,
     permission_import_setup_edit, permission_import_setup_process,
@@ -12,11 +12,138 @@ from ..permissions import (
 )
 
 from .mixins import (
+    ImportSetupActionTestMixin, ImportSetupActionViewTestMixin,
     ImportSetupTestMixin, ImportSetupItemTestMixin, ImportSetupViewTestMixin,
     ImportSetupItemViewTestMixin
 )
 
 
+class ImportSetupActionViewTestCase(
+    CredentialTestMixin, DocumentTestMixin, ImportSetupActionTestMixin,
+    ImportSetupActionViewTestMixin, ImportSetupTestMixin, GenericViewTestCase
+):
+    auto_upload_test_document = False
+
+    def setUp(self):
+        super().setUp()
+        self._create_test_credential()
+        self._create_test_import_setup()
+
+    def test_import_setup_action_backend_selection_view_no_permissions(self):
+        import_setup_action_count = ImportSetupAction.objects.count()
+
+        response = self._request_test_import_setup_action_backend_selection_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertEqual(ImportSetupAction.objects.count(), import_setup_action_count)
+
+    def test_import_setup_action_backend_selection_view_with_permissions(self):
+        self.grant_access(
+            obj=self.test_import_setup, permission=permission_import_setup_edit
+        )
+        import_setup_action_count = ImportSetupAction.objects.count()
+
+        response = self._request_test_import_setup_action_backend_selection_view()
+        self.assertEqual(response.status_code, 302)
+
+        self.assertEqual(ImportSetupAction.objects.count(), import_setup_action_count)
+
+    def test_import_setup_action_create_view_no_permissions(self):
+        import_setup_action_count = ImportSetupAction.objects.count()
+
+        response = self._request_test_import_setup_action_create_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertEqual(ImportSetupAction.objects.count(), import_setup_action_count)
+
+    def test_import_setup_action_create_view_with_permissions(self):
+        self.grant_access(
+            obj=self.test_import_setup, permission=permission_import_setup_edit
+        )
+        import_setup_action_count = ImportSetupAction.objects.count()
+
+        response = self._request_test_import_setup_action_create_view()
+        self.assertEqual(response.status_code, 302)
+
+        self.assertEqual(
+            ImportSetupAction.objects.count(), import_setup_action_count + 1
+        )
+
+    def test_import_setup_action_delete_view_no_permissions(self):
+        self._create_test_import_setup_action()
+
+        import_setup_action_count = ImportSetupAction.objects.count()
+
+        response = self._request_test_import_setup_action_delete_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertEqual(ImportSetupAction.objects.count(), import_setup_action_count)
+
+    def test_import_setup_action_delete_view_with_access(self):
+        self._create_test_import_setup_action()
+
+        self.grant_access(
+            obj=self.test_import_setup, permission=permission_import_setup_edit
+        )
+
+        import_setup_action_count = ImportSetupAction.objects.count()
+
+        response = self._request_test_import_setup_action_delete_view()
+        self.assertEqual(response.status_code, 302)
+
+        self.assertEqual(
+            ImportSetupAction.objects.count(), import_setup_action_count - 1
+        )
+
+    def test_import_setup_action_edit_view_no_permissions(self):
+        self._create_test_import_setup_action()
+
+        import_setup_action_label = self.test_import_setup_action.label
+
+        response = self._request_test_import_setup_action_edit_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.test_import_setup_action.refresh_from_db()
+        self.assertEqual(self.test_import_setup_action.label, import_setup_action_label)
+
+    def test_import_setup_action_edit_view_with_access(self):
+        self._create_test_import_setup_action()
+
+        self.grant_access(
+            obj=self.test_import_setup, permission=permission_import_setup_edit
+        )
+
+        import_setup_action_label = self.test_import_setup_action.label
+
+        response = self._request_test_import_setup_action_edit_view()
+        self.assertEqual(response.status_code, 302)
+
+        self.test_import_setup_action.refresh_from_db()
+        self.assertNotEqual(self.test_import_setup_action.label, import_setup_action_label)
+
+    def test_import_setup_action_list_view_with_no_permission(self):
+        self._create_test_import_setup_action()
+
+        response = self._request_test_import_setup_action_list_view()
+        self.assertNotContains(
+            response=response, text=self.test_import_setup_action.label,
+            status_code=404
+        )
+
+    def test_import_setup_action_list_view_with_access(self):
+        self._create_test_import_setup_action()
+
+        self.grant_access(
+            obj=self.test_import_setup, permission=permission_import_setup_view
+        )
+
+        response = self._request_test_import_setup_action_list_view()
+        self.assertContains(
+            response=response, text=self.test_import_setup_action.label,
+            status_code=200
+        )
+
+
 class ImportSetupViewTestCase(
     CredentialTestMixin, DocumentTestMixin, ImportSetupTestMixin,
     ImportSetupViewTestMixin, GenericViewTestCase
