@@ -1,12 +1,15 @@
 from django.conf.urls import url
 
 from .views import (
-    ImportSetupBackendSelectionView, ImportSetupCreateView,
-    ImportSetupDeleteView, ImportSetupEditView, ImportSetupProcessView,
-    ImportSetupClearView, ImportSetupListView, ImportSetupPopulateView,
-    ImportSetupItemDeleteView, ImportSetupItemListView,
-    ImportSetupItemLoadView, ImportSetupItemProcessView,
-    ImportSetupItemSaveConfirmView, ImportSetupItemSaveDownloadView
+    ImportSetupActionCreateView, ImportSetupActionDeleteView,
+    ImportSetupActionEditView, ImportSetupActionListView,
+    ImportSetupActionBackendSelectionView, ImportSetupBackendSelectionView,
+    ImportSetupCreateView, ImportSetupDeleteView, ImportSetupEditView,
+    ImportSetupProcessView, ImportSetupClearView, ImportSetupListView,
+    ImportSetupPopulateView, ImportSetupItemDeleteView,
+    ImportSetupItemListView, ImportSetupItemLoadView,
+    ImportSetupItemProcessView, ImportSetupItemSaveConfirmView,
+    ImportSetupItemSaveDownloadView
 )
 
 urlpatterns_import_setup = [
@@ -34,6 +37,34 @@ urlpatterns_import_setup = [
     ),
 ]
 
+urlpatterns_import_setup_actions = [
+    url(
+        regex=r'^import_setups/(?P<import_setup_id>\d+)/actions/$',
+        name='import_setup_action_list',
+        view=ImportSetupActionListView.as_view()
+    ),
+    url(
+        regex=r'^import_setups/(?P<import_setup_id>\d+)/actions/(?P<class_path>[a-zA-Z0-9_.]+)/create/$',
+        name='import_setup_action_create',
+        view=ImportSetupActionCreateView.as_view()
+    ),
+    url(
+        regex=r'^import_setups/actions/(?P<import_setup_action_id>\d+)/delete/$',
+        name='import_setup_action_delete',
+        view=ImportSetupActionDeleteView.as_view()
+    ),
+    url(
+        regex=r'^import_setups/actions/(?P<import_setup_action_id>\d+)/edit/$',
+        name='import_setup_action_edit',
+        view=ImportSetupActionEditView.as_view()
+    ),
+    url(
+        regex=r'^import_setups/(?P<import_setup_id>\d+)/actions/selection/$',
+        name='import_setup_action_backend_selection',
+        view=ImportSetupActionBackendSelectionView.as_view()
+    ),
+]
+
 urlpatterns_import_setup_items = [
     url(
         regex=r'^import_setups/(?P<import_setup_id>\d+)/clear/$',
@@ -99,4 +130,5 @@ urlpatterns_import_setup_items = [
 
 urlpatterns = []
 urlpatterns.extend(urlpatterns_import_setup)
+urlpatterns.extend(urlpatterns_import_setup_actions)
 urlpatterns.extend(urlpatterns_import_setup_items)
